@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 my $log;
 my $bcmd;
@@ -134,7 +134,6 @@ sub instance_install {
                         $log->_7("MSWin: no 64-bit version... using $version");
                     }
                 }
-
             }
             $version =~ s/_.*$// if ! $self->is_win;
 
@@ -153,8 +152,13 @@ sub instance_install {
     elsif ($install) {
         $log->_5("looking to install $install perl instance(s)");
 
+        my %avail = map {$_ => 1} @perls_available;
+
         while ($install > 0){
-            my $candidate = $perls_available[rand @perls_available];
+            last if ! keys %avail;
+
+            my $candidate = (keys %avail)[rand keys %avail];
+            delete $avail{$candidate};
 
             if (grep { $_ eq $candidate } @perls_installed) {
                 $log->_6( "$candidate already installed... skipping" );
@@ -310,7 +314,7 @@ sub test {
     for my $result (@ver_results){
         my $ver;
 
-        if ($result =~ /^([Pp]erl-\d\.\d+\.\d+)/){
+        if ($result =~ /^([Pp]erl-\d\.\d+\.\d+(_\d{2})?)/){
             $ver = $1;
             $ver =~ s/[Pp]erl-//;
         }
@@ -341,6 +345,7 @@ sub test {
     $ret .= "$self->{args}{plugin_arg}\n" if $self->{args}{plugin_arg};
     $ret .= $_ for @pass;
     $ret .= $_ for @fail;
+    $ret .= "\n\n";
 
     return $ret;
 }
