@@ -12,7 +12,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 $| = 1;
 
@@ -165,6 +165,8 @@ sub _fork {
     for my $tester (keys %$remotes){
         $log->_7("spinning up tester: $tester");
 
+        my $log = $log->child($tester);
+
         $pm->start and next CLIENTS;
 
         my %return;
@@ -228,11 +230,12 @@ sub _fork {
             }
             $socket->send($repo_link);
 
-            eval {
+            my $ok = eval {
                 $return{$tester}{build} = Storable::fd_retrieve($socket);
+                1;
             };
 
-            if ($@){
+            if (! $ok){
                 $log->_0("errors occurred... check your command line " .
                          "string for invalid args. You sent in: $cmd"
                 );
